package com.persagy.proxy.adm.service;

import java.util.List;

import com.fasterxml.jackson.databind.node.ObjectNode;
import com.persagy.dmp.digital.entity.ObjectRelation;
import com.persagy.proxy.adm.model.AdmRelationObject;

/**
 * 报表/模板下载
 * 
 * @version 1.0.0
 * @company persagy 
 * @author zhangqiankun
 * @date 2021年8月31日 下午4:42:51
 */
public interface IRelationReportService {

	/**
	 * 获取指定对象信息
	 * 
	 * @param groupCode
	 * @param projectId
	 * @param id
	 * @return 不会返回null
	 */
	ObjectNode getObjectNode(String groupCode, String projectId, String id);
	
	/**
	 * 获取指定对象信息
	 * <p>定制接口，不建议兼容额外的处理方案</p>
	 * 
	 * @param groupCode
	 * @param projectId
	 * @param objType
	 * @param code	ADM-中的code类型，请参考{@link com.persagy.proxy.adm.strategy.relationdata.QueryRelationObjectStrategy#OBJNAME_2_TYPE}
	 * @param value 属性值
	 * @return
	 */
	List<ObjectNode> findObjectNodes(String groupCode, String projectId, String objType, String code, String value);
	
	/**
	 * 获取对象，通过关系对象的id和rel_code
	 * 
	 * @param groupCode
	 * @param projectId
	 * @param graphCode
	 * @param relCode
	 * @param objFrom 与objTo不可同时存在
	 * @param objTo	  与objFrom不可同时存在
	 * @return 不会返回null
	 */
	ObjectNode getObjectByCodeAndId(String groupCode, String projectId, String graphCode, String relCode, String objFrom, String objTo);
	
	/**
	 * 获取对象关系数据
	 * 
	 * @param groupCode
	 * @param projectId
	 * @param graphCode
	 * @param relCode
	 * @return
	 */
	List<ObjectRelation> findObjectRelationList(String groupCode, String projectId, String graphCode, String relCode);
	
	/**
	 * 查询出所有的关系信息
	 * <p>因原代码中，不存在zoneType类型不为空时对应的方法，所以此处不再进行此数据的判断</p>
	 * 
	 * @param groupCode
	 * @param projectId
	 * @param relType
	 * @param code
	 * @param zoneType
	 * @return 可以被直接导出的数据集
	 */
	List<AdmRelationObject> reportRelationObject(String groupCode, String projectId, String relType, String code, String zoneType);
	
}
